@@ -8,11 +8,17 @@ use crate::{
 };
 use std::sync::{Arc, Mutex};
 pub use test_device::{
-  TestDevice, TestDeviceEndpointChannel, TestDeviceImplCreator, TestDeviceInternal,
+  TestDevice,
+  TestDeviceEndpointChannel,
+  TestDeviceImplCreator,
+  TestDeviceInternal,
 };
 #[cfg(feature = "server")]
 pub use test_device_comm_manager::{
-  new_bluetoothle_test_device, TestDeviceCommunicationManager, TestDeviceCommunicationManagerHelper, TestDeviceCommunicationManagerBuilder
+  new_bluetoothle_test_device,
+  TestDeviceCommunicationManager,
+  TestDeviceCommunicationManagerBuilder,
+  TestDeviceCommunicationManagerHelper,
 };
 use tokio::sync::mpsc::Receiver;
 
@@ -22,12 +28,14 @@ pub fn check_test_recv_value(
   command: DeviceImplCommand,
 ) {
   assert_eq!(
-    recv_now(&mut receiver.lock().unwrap()).unwrap().unwrap(),
+    recv_now(&mut receiver.lock().expect("Test"))
+      .expect("No messages received")
+      .expect("Test"),
     command
   );
 }
 
 #[allow(dead_code)]
 pub fn check_test_recv_empty(receiver: &Arc<Mutex<Receiver<DeviceImplCommand>>>) -> bool {
-  iffy_is_empty_check(&mut receiver.lock().unwrap())
+  iffy_is_empty_check(&mut receiver.lock().expect("Test"))
 }
