@@ -8,17 +8,13 @@
 //! JSON Schema validator structure, used by the
 //! [DeviceConfigurationManager][crate::device::configuration_manager::DeviceConfigurationManager] and
 //! buttplug message de/serializers in both the client and server. Uses the
-//! Valico library.
+//! jsonschema library.
 
 use crate::core::messages::serializer::ButtplugSerializerError;
-use serde_json::Value;
-use valico::json_schema;
+use jsonschema::JSONSchema;
 
 pub struct JSONValidator {
-  /// Valico's scope object, used for holding the schema.
-  scope: json_schema::scope::Scope,
-  /// Valico's id URL, used for accessing the schema.
-  id: url::Url,
+  schema: JSONSchema
 }
 
 impl JSONValidator {
@@ -28,13 +24,9 @@ impl JSONValidator {
   ///
   /// - `schema`: JSON Schema that the validator should use.
   pub fn new(schema: &str) -> Self {
-    let schema_json: Value =
-      serde_json::from_str(schema).expect("If this fails, the library is going with it.");
-    let mut scope = json_schema::Scope::new();
-    let id = scope
-      .compile(schema_json, false)
-      .expect("If this fails, the library is going with it.");
-    Self { id, scope }
+    let schema_json: serde_json::Value = serde_json::from_str(schema).expect("Built in schema better be valid");
+    let schema = JSONSchema::compile(&schema_json).expect("Built in schema better be valid");
+    Self { schema }
   }
 
   /// Validates a json string, based on the schema the validator was created
@@ -44,27 +36,15 @@ impl JSONValidator {
   ///
   /// - `json_str`: JSON string to validate.
   pub fn validate(&self, json_str: &str) -> Result<(), ButtplugSerializerError> {
-    let schema = self
-      .scope
-      .resolve(&self.id)
-      .expect("id generated on creation.");
     let check_value = serde_json::from_str(json_str).map_err(|err| {
       ButtplugSerializerError::JsonSerializerError(format!(
         "Message: {} - Error: {:?}",
         json_str, err
       ))
     })?;
-    let state = schema.validate(&check_value);
-    if state.is_valid() {
-      Ok(())
-    } else {
-      // Our errors need to be clonable, and validation state isn't. We can't do
-      // much with it anyways, so just convert it to its display and hand that
-      // back.
-      Err(ButtplugSerializerError::JsonValidatorError(format!(
-        "Message: {} - Error: {:?}",
-        json_str, state
-      )))
-    }
+    self.schema.validate(&check_value).map_err(|err| {
+      let err_vec: Vec<jsonschema::ValidationError> = err.collect();
+      ButtplugSerializerError::JsonSerializerError(format!("Error during JSON Schema Validation: {:?}", err_vec))
+    })
   }
 }
